*------------------------------------------------------------*;
* AutoNeural: Create decision matrix;
*------------------------------------------------------------*;
data WORK.REP_hitel(label="REP_hitel");
  length   REP_hitel                        $  32
           COUNT                                8
           DATAPRIOR                            8
           TRAINPRIOR                           8
           DECPRIOR                             8
           DECISION1                            8
           DECISION2                            8
           ;

  infile   cards  dsd;

  input    REP_hitel $
           COUNT
           DATAPRIOR
           TRAINPRIOR
           DECPRIOR
           DECISION1
           DECISION2
           ;

  label    COUNT="Level Counts"
           DATAPRIOR="Data Proportions"
           TRAINPRIOR="Training Proportions"
           DECPRIOR="Decision Priors"
           DECISION1="1"
           DECISION2="0"
           ;
  informat REP_hitel $CHAR32.
           ;
cards;
1,3402,0.45960551202377,0.45960551202377,.,1,0
0,4000,0.54039448797622,0.54039448797622,.,0,1
;
run;
proc datasets lib=work nolist;
modify REP_hitel(type=PROFIT label=REP_hitel);
label DECISION1= "1";
label DECISION2= "0";
run;
quit;
*------------------------------------------------------------* ;
* AutoNeural: DMDBClass Macro ;
*------------------------------------------------------------* ;
%macro DMDBClass;
    GRP_IMP_REP_ESNJ(ASC) GRP_REP_HNJE(ASC) REP_HEPTEL(ASC) REP_HKOMP(ASC)
   REP_HLAKA(ASC) REP_HLBER(ASC) REP_HLFUT(ASC) REP_HLGAZF(ASC) REP_HLHIT(ASC)
   REP_HLKTG(ASC) REP_HLKTR(ASC) REP_HLTIP(ASC) REP_HLTOR(ASC) REP_HLVIL(ASC)
   REP_HLVIZ(ASC) REP_HMEZFOL(ASC) REP_HMLAK(ASC) REP_HMOTOKC(ASC) REP_HUD(ASC)
   REP_SBISK1(ASC) REP_SBISK3(ASC) REP_SCSAL(ASC) REP_SCSAP(ASC) REP_SDOHE(ASC)
   REP_SGYOR(ASC) REP_SHAZTFO(ASC) REP_SKAVE(ASC) REP_SNEME(ASC)
   REP_TRA_HCTSZGA(ASC) REP_TRA_HMOTOKA(ASC) REP_TRA_HMOTOKB(ASC)
   REP_TRA_HMOTOKC(ASC) REP_TRA_HMOTOVA(ASC) REP_TRA_HMOTOVB(ASC)
   REP_TRA_HMOTOVC(ASC) REP_TRA_HSTSZGA(ASC) REP_TRA_HSTSZGB(ASC)
   REP_TRA_HSTSZGC(ASC) REP_hitel(DESC)
%mend DMDBClass;
*------------------------------------------------------------* ;
* AutoNeural: DMDBVar Macro ;
*------------------------------------------------------------* ;
%macro DMDBVar;
    HLAKFT HLANM HLETS SZKOR TRA_HAERT
%mend DMDBVar;
*------------------------------------------------------------*;
* AutoNeural: Create DMDB;
*------------------------------------------------------------*;
proc dmdb batch data=EMWS.BINNING_TRAIN dmdbcat=WORK.AutoNeural_DMDB
maxlevel = 513
;
class %DMDBClass;
var %DMDBVar;
target
REP_hitel
;
run;
quit;
*------------------------------------------------------------* ;
* AutoNeural: Interval Inputs Macro ;
*------------------------------------------------------------* ;
%macro INTINPUTS;
    HLAKFT HLANM HLETS SZKOR TRA_HAERT
%mend INTINPUTS;
*------------------------------------------------------------* ;
* AutoNeural: Binary Inputs Macro ;
*------------------------------------------------------------* ;
%macro BININPUTS;
    REP_TRA_HMOTOKA REP_TRA_HMOTOVA
%mend BININPUTS;
*------------------------------------------------------------* ;
* AutoNeural: Nominal Inputs Macro ;
*------------------------------------------------------------* ;
%macro NOMINPUTS;
    REP_HEPTEL REP_HKOMP REP_HLAKA REP_HLBER REP_HLFUT REP_HLGAZF REP_HLHIT
   REP_HLKTG REP_HLKTR REP_HLTIP REP_HLTOR REP_HLVIL REP_HLVIZ REP_HMEZFOL
   REP_HMLAK REP_HMOTOKC REP_HUD REP_SBISK1 REP_SBISK3 REP_SCSAL REP_SCSAP
   REP_SDOHE REP_SGYOR REP_SHAZTFO REP_SKAVE REP_SNEME REP_TRA_HCTSZGA
   REP_TRA_HMOTOKB REP_TRA_HMOTOKC REP_TRA_HMOTOVB REP_TRA_HMOTOVC REP_TRA_HSTSZGA
   REP_TRA_HSTSZGB REP_TRA_HSTSZGC
%mend NOMINPUTS;
*------------------------------------------------------------* ;
* AutoNeural: Ordinal Inputs Macro ;
*------------------------------------------------------------* ;
%macro ORDINPUTS;
    GRP_IMP_REP_ESNJ GRP_REP_HNJE
%mend ORDINPUTS;
* set printing options;
;
options linesize = 80;
options pagesize = 6000;
options nonumber;
options nocenter;
options nodate;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_autonet_title  , NOQUOTE))";
*;
*------------------------------------------------------------*;
* Autoneural: search / CASCADE;
;
*------------------------------------------------------------*;
*;
proc neural data=EMWS.BINNING_TRAIN dmdbcat=WORK.AutoNeural_DMDB
;
input %INTINPUTS / level=interval id=interval;
input %BININPUTS / level=nominal id=binary;
input %NOMINPUTS / level=nominal id=nominal;
input %ORDINPUTS / level=ordinal id=ordinal;
target REP_hitel / level=NOMINAL id=REP_hitel
;
*------------------------------------------------------------*;
* Direct connection;
;
*------------------------------------------------------------*;
connect interval REP_hitel;
connect binary REP_hitel;
connect nominal REP_hitel;
connect ordinal REP_hitel;
*------------------------------------------------------------*;
* Layer #1;
;
*------------------------------------------------------------*;
Hidden 1 / id = H1x1_ act=TANH;
connect interval H1x1_;
connect binary H1x1_;
connect nominal H1x1_;
connect ordinal H1x1_;
connect H1x1_ REP_hitel;
*;
netoptions ranscale = 1;
*;
nloptions noprint;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_prelim_title  ,NOQUOTE, Search # 1 CASCADE trial # 1 : TANH : ))";
prelim 6 outest=_anpre pretime=149 preiter=8
tech = Default
;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_train_title  ,NOQUOTE, Search # 1 CASCADE trial # 1 : TANH : ))";
train estiter=1 outest=_anest outfit=_anfit maxtime=899 maxiter=8
tech = Default;
;
run;
*;
proc print data=_anfit(where=(_name_ eq 'OVERALL')) noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
*------------------------------------------------------------*;
* Extract best iteration;
;
*------------------------------------------------------------*;
%global _iter;
data _null_;
set _anfit(where=(_NAME_ eq 'OVERALL'));
retain _min 1e+64;
if _MISC_ < _min then do;
_min = _MISC_;
call symput('_iter',put(_ITER_, 6.));
end;
run;
*;
data EMWS.AutoNeural_ESTDS;
set _anest;
if _ITER_ eq 0 then do;
output;
stop;
end;
run;
*;
data EMWS.AutoNeural_OUTFIT;
set _anfit;
if _ITER_ eq 0 and _NAME_ eq "OVERALL" then do;
output;
stop;
end;
run;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_selectediteration_title  , NOQUOTE, _MISC_))";
proc print data=EMWS.AutoNeural_OUTFIT noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
title9;
title10;
%sysfunc(sasmsg(sashelp.dmine, starthistory_note , NOQUOTE));
data EMWS.AutoNeural_HISTORY;
length _func_ _status_ _step_ $16;
label _func_ = "%sysfunc(sasmsg(sashelp.dmine, rpt_function_vlabel  , NOQUOTE))";
label _status_ = "%sysfunc(sasmsg(sashelp.dmine, rpt_status_vlabel  , NOQUOTE))";
label _iter_ = "%sysfunc(sasmsg(sashelp.dmine, rpt_iteration_vlabel  , NOQUOTE))";
label _step_ = "%sysfunc(sasmsg(sashelp.dmine, rpt_step_vlabel  , NOQUOTE))";
_func_ = '';
_status_ = '';
_step_ = 'CASCADE 1';
set
_anfit(where=(_name_ eq 'OVERALL' and _iter_ eq 0))
;
run;
*;
proc neural data=EMWS.BINNING_TRAIN dmdbcat=WORK.AutoNeural_DMDB
;
input %INTINPUTS / level=interval id=interval;
input %BININPUTS / level=nominal id=binary;
input %NOMINPUTS / level=nominal id=nominal;
input %ORDINPUTS / level=ordinal id=ordinal;
target REP_hitel / level=NOMINAL id=REP_hitel
;
*------------------------------------------------------------*;
* Direct connection;
;
*------------------------------------------------------------*;
connect interval REP_hitel;
connect binary REP_hitel;
connect nominal REP_hitel;
connect ordinal REP_hitel;
*------------------------------------------------------------*;
* Layer #1;
;
*------------------------------------------------------------*;
Hidden 1 / id = H1x1_ act=GAUSS;
connect interval H1x1_;
connect binary H1x1_;
connect nominal H1x1_;
connect ordinal H1x1_;
connect H1x1_ REP_hitel;
*;
netoptions ranscale = 1;
*;
initial
;
*;
nloptions noprint;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_prelim_title  ,NOQUOTE, Search # 1 CASCADE trial # 2 : NORMAL : ))";
prelim 6 outest=_anpre pretime=149 preiter=8
tech = Default
;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_train_title  ,NOQUOTE, Search # 1 CASCADE trial # 2 : NORMAL : ))";
train estiter=1 outest=_anest outfit=_anfit maxtime=897 maxiter=8
tech = Default;
;
run;
*;
proc print data=_anfit(where=(_name_ eq 'OVERALL')) noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
*------------------------------------------------------------*;
* Extract best iteration;
;
*------------------------------------------------------------*;
%global _iter;
data _null_;
set _anfit(where=(_NAME_ eq 'OVERALL'));
retain _min 1e+64;
if _MISC_ < _min then do;
_min = _MISC_;
call symput('_iter',put(_ITER_, 6.));
end;
run;
*;
data EMWS.AutoNeural_ESTDS;
set _anest;
if _ITER_ eq 0 then do;
output;
stop;
end;
run;
*;
data EMWS.AutoNeural_OUTFIT;
set _anfit;
if _ITER_ eq 0 and _NAME_ eq "OVERALL" then do;
output;
stop;
end;
run;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_selectediteration_title  , NOQUOTE, _MISC_))";
proc print data=EMWS.AutoNeural_OUTFIT noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
title9;
title10;
*;
proc neural data=EMWS.BINNING_TRAIN dmdbcat=WORK.AutoNeural_DMDB
;
input %INTINPUTS / level=interval id=interval;
input %BININPUTS / level=nominal id=binary;
input %NOMINPUTS / level=nominal id=nominal;
input %ORDINPUTS / level=ordinal id=ordinal;
target REP_hitel / level=NOMINAL id=REP_hitel
;
*------------------------------------------------------------*;
* Direct connection;
;
*------------------------------------------------------------*;
connect interval REP_hitel;
connect binary REP_hitel;
connect nominal REP_hitel;
connect ordinal REP_hitel;
*------------------------------------------------------------*;
* Layer #1;
;
*------------------------------------------------------------*;
Hidden 1 / id = H1x1_ act=SINE;
connect interval H1x1_;
connect binary H1x1_;
connect nominal H1x1_;
connect ordinal H1x1_;
connect H1x1_ REP_hitel;
*;
netoptions ranscale = 1;
*;
initial
;
*;
nloptions noprint;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_prelim_title  ,NOQUOTE, Search # 1 CASCADE trial # 3 : SINE : ))";
prelim 6 outest=_anpre pretime=148 preiter=8
tech = Default
;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_train_title  ,NOQUOTE, Search # 1 CASCADE trial # 3 : SINE : ))";
train estiter=1 outest=_anest outfit=_anfit maxtime=893 maxiter=8
tech = Default;
;
run;
*;
proc print data=_anfit(where=(_name_ eq 'OVERALL')) noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
*------------------------------------------------------------*;
* Extract best iteration;
;
*------------------------------------------------------------*;
%global _iter;
data _null_;
set _anfit(where=(_NAME_ eq 'OVERALL'));
retain _min 1e+64;
if _MISC_ < _min then do;
_min = _MISC_;
call symput('_iter',put(_ITER_, 6.));
end;
run;
*;
data EMWS.AutoNeural_ESTDS;
set _anest;
if _ITER_ eq 0 then do;
output;
stop;
end;
run;
*;
data EMWS.AutoNeural_OUTFIT;
set _anfit;
if _ITER_ eq 0 and _NAME_ eq "OVERALL" then do;
output;
stop;
end;
run;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_selectediteration_title  , NOQUOTE, _MISC_))";
proc print data=EMWS.AutoNeural_OUTFIT noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
title9;
title10;
*;
proc neural data=EMWS.BINNING_TRAIN dmdbcat=WORK.AutoNeural_DMDB
;
input %INTINPUTS / level=interval id=interval;
input %BININPUTS / level=nominal id=binary;
input %NOMINPUTS / level=nominal id=nominal;
input %ORDINPUTS / level=ordinal id=ordinal;
target REP_hitel / level=NOMINAL id=REP_hitel
;
*------------------------------------------------------------*;
* Direct connection;
;
*------------------------------------------------------------*;
connect interval REP_hitel;
connect binary REP_hitel;
connect nominal REP_hitel;
connect ordinal REP_hitel;
*------------------------------------------------------------*;
* Layer #1;
;
*------------------------------------------------------------*;
Hidden 1 / id = H1x1_ act=TANH;
connect interval H1x1_;
connect binary H1x1_;
connect nominal H1x1_;
connect ordinal H1x1_;
connect H1x1_ REP_hitel;
*------------------------------------------------------------*;
* Layer #2;
;
*------------------------------------------------------------*;
Hidden 1 / id = H2x1_ act=TANH;
connect interval H2x1_;
connect binary H2x1_;
connect nominal H2x1_;
connect ordinal H2x1_;
connect H1x1_ H2x1_;
connect H2x1_ REP_hitel;
*;
netoptions ranscale = 0.55;
*;
initial
inest = EMWS.AutoNeural_ESTDS bylabel;
;
*;
Freeze interval -> H1x1_;
Freeze binary -> H1x1_;
Freeze nominal -> H1x1_;
Freeze ordinal -> H1x1_;
Freeze bias -> H1x1_;
*;
nloptions noprint;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_prelim_title  ,NOQUOTE, Search # 2 CASCADE trial # 1 : TANH : ))";
prelim 6 outest=_anpre pretime=148 preiter=8
tech = Default
inest = EMWS.AutoNeural_ESTDS bylabel
;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_train_title  ,NOQUOTE, Search # 2 CASCADE trial # 1 : TANH : ))";
train estiter=1 outest=_anest outfit=_anfit maxtime=891 maxiter=8
tech = Default;
;
run;
*;
proc print data=_anfit(where=(_name_ eq 'OVERALL')) noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
*------------------------------------------------------------*;
* Extract best iteration;
;
*------------------------------------------------------------*;
%global _iter;
data _null_;
set _anfit(where=(_NAME_ eq 'OVERALL'));
retain _min 1e+64;
if _MISC_ < _min then do;
_min = _MISC_;
call symput('_iter',put(_ITER_, 6.));
end;
run;
*;
data EMWS.AutoNeural_ESTDS;
set _anest;
if _ITER_ eq 0 then do;
output;
stop;
end;
run;
*;
data EMWS.AutoNeural_OUTFIT;
set _anfit;
if _ITER_ eq 0 and _NAME_ eq "OVERALL" then do;
output;
stop;
end;
run;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_selectediteration_title  , NOQUOTE, _MISC_))";
proc print data=EMWS.AutoNeural_OUTFIT noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
title9;
title10;
*;
proc neural data=EMWS.BINNING_TRAIN dmdbcat=WORK.AutoNeural_DMDB
;
input %INTINPUTS / level=interval id=interval;
input %BININPUTS / level=nominal id=binary;
input %NOMINPUTS / level=nominal id=nominal;
input %ORDINPUTS / level=ordinal id=ordinal;
target REP_hitel / level=NOMINAL id=REP_hitel
;
*------------------------------------------------------------*;
* Direct connection;
;
*------------------------------------------------------------*;
connect interval REP_hitel;
connect binary REP_hitel;
connect nominal REP_hitel;
connect ordinal REP_hitel;
*------------------------------------------------------------*;
* Layer #1;
;
*------------------------------------------------------------*;
Hidden 1 / id = H1x1_ act=TANH;
connect interval H1x1_;
connect binary H1x1_;
connect nominal H1x1_;
connect ordinal H1x1_;
connect H1x1_ REP_hitel;
*------------------------------------------------------------*;
* Layer #2;
;
*------------------------------------------------------------*;
Hidden 1 / id = H2x1_ act=GAUSS;
connect interval H2x1_;
connect binary H2x1_;
connect nominal H2x1_;
connect ordinal H2x1_;
connect H1x1_ H2x1_;
connect H2x1_ REP_hitel;
*;
netoptions ranscale = 0.55;
*;
initial
inest = EMWS.AutoNeural_ESTDS bylabel;
;
*;
Freeze interval -> H1x1_;
Freeze binary -> H1x1_;
Freeze nominal -> H1x1_;
Freeze ordinal -> H1x1_;
Freeze bias -> H1x1_;
*;
nloptions noprint;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_prelim_title  ,NOQUOTE, Search # 2 CASCADE trial # 2 : NORMAL : ))";
prelim 6 outest=_anpre pretime=148 preiter=8
tech = Default
inest = EMWS.AutoNeural_ESTDS bylabel
;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_train_title  ,NOQUOTE, Search # 2 CASCADE trial # 2 : NORMAL : ))";
train estiter=1 outest=_anest outfit=_anfit maxtime=889 maxiter=8
tech = Default;
;
run;
*;
proc print data=_anfit(where=(_name_ eq 'OVERALL')) noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
*------------------------------------------------------------*;
* Extract best iteration;
;
*------------------------------------------------------------*;
%global _iter;
data _null_;
set _anfit(where=(_NAME_ eq 'OVERALL'));
retain _min 1e+64;
if _MISC_ < _min then do;
_min = _MISC_;
call symput('_iter',put(_ITER_, 6.));
end;
run;
*;
data EMWS.AutoNeural_ESTDS;
set _anest;
if _ITER_ eq 0 then do;
output;
stop;
end;
run;
*;
data EMWS.AutoNeural_OUTFIT;
set _anfit;
if _ITER_ eq 0 and _NAME_ eq "OVERALL" then do;
output;
stop;
end;
run;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_selectediteration_title  , NOQUOTE, _MISC_))";
proc print data=EMWS.AutoNeural_OUTFIT noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
title9;
title10;
*;
proc neural data=EMWS.BINNING_TRAIN dmdbcat=WORK.AutoNeural_DMDB
;
input %INTINPUTS / level=interval id=interval;
input %BININPUTS / level=nominal id=binary;
input %NOMINPUTS / level=nominal id=nominal;
input %ORDINPUTS / level=ordinal id=ordinal;
target REP_hitel / level=NOMINAL id=REP_hitel
;
*------------------------------------------------------------*;
* Direct connection;
;
*------------------------------------------------------------*;
connect interval REP_hitel;
connect binary REP_hitel;
connect nominal REP_hitel;
connect ordinal REP_hitel;
*------------------------------------------------------------*;
* Layer #1;
;
*------------------------------------------------------------*;
Hidden 1 / id = H1x1_ act=TANH;
connect interval H1x1_;
connect binary H1x1_;
connect nominal H1x1_;
connect ordinal H1x1_;
connect H1x1_ REP_hitel;
*------------------------------------------------------------*;
* Layer #2;
;
*------------------------------------------------------------*;
Hidden 1 / id = H2x1_ act=SINE;
connect interval H2x1_;
connect binary H2x1_;
connect nominal H2x1_;
connect ordinal H2x1_;
connect H1x1_ H2x1_;
connect H2x1_ REP_hitel;
*;
netoptions ranscale = 0.55;
*;
initial
inest = EMWS.AutoNeural_ESTDS bylabel;
;
*;
Freeze interval -> H1x1_;
Freeze binary -> H1x1_;
Freeze nominal -> H1x1_;
Freeze ordinal -> H1x1_;
Freeze bias -> H1x1_;
*;
nloptions noprint;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_prelim_title  ,NOQUOTE, Search # 2 CASCADE trial # 3 : SINE : ))";
prelim 6 outest=_anpre pretime=148 preiter=8
tech = Default
inest = EMWS.AutoNeural_ESTDS bylabel
;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_train_title  ,NOQUOTE, Search # 2 CASCADE trial # 3 : SINE : ))";
train estiter=1 outest=_anest outfit=_anfit maxtime=888 maxiter=8
tech = Default;
;
run;
*;
proc print data=_anfit(where=(_name_ eq 'OVERALL')) noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
*------------------------------------------------------------*;
* Extract best iteration;
;
*------------------------------------------------------------*;
%global _iter;
data _null_;
set _anfit(where=(_NAME_ eq 'OVERALL'));
retain _min 1e+64;
if _MISC_ < _min then do;
_min = _MISC_;
call symput('_iter',put(_ITER_, 6.));
end;
run;
*;
data EMWS.AutoNeural_ESTDS;
set _anest;
if _ITER_ eq 0 then do;
output;
stop;
end;
run;
*;
data EMWS.AutoNeural_OUTFIT;
set _anfit;
if _ITER_ eq 0 and _NAME_ eq "OVERALL" then do;
output;
stop;
end;
run;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_selectediteration_title  , NOQUOTE, _MISC_))";
proc print data=EMWS.AutoNeural_OUTFIT noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
title9;
title10;
*;
proc neural data=EMWS.BINNING_TRAIN dmdbcat=WORK.AutoNeural_DMDB
;
input %INTINPUTS / level=interval id=interval;
input %BININPUTS / level=nominal id=binary;
input %NOMINPUTS / level=nominal id=nominal;
input %ORDINPUTS / level=ordinal id=ordinal;
target REP_hitel / level=NOMINAL id=REP_hitel
;
*------------------------------------------------------------*;
* Direct connection;
;
*------------------------------------------------------------*;
connect interval REP_hitel;
connect binary REP_hitel;
connect nominal REP_hitel;
connect ordinal REP_hitel;
*------------------------------------------------------------*;
* Layer #1;
;
*------------------------------------------------------------*;
Hidden 1 / id = H1x1_ act=TANH;
connect interval H1x1_;
connect binary H1x1_;
connect nominal H1x1_;
connect ordinal H1x1_;
connect H1x1_ REP_hitel;
*;
netoptions ranscale = 0.55;
*;
initial
inest = EMWS.AutoNeural_ESTDS bylabel;
;
*;
Freeze interval -> H1x1_;
Freeze binary -> H1x1_;
Freeze nominal -> H1x1_;
Freeze ordinal -> H1x1_;
Freeze bias -> H1x1_;
*;
nloptions noprint;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_prelim_title  ,NOQUOTE, Final Training))";
prelim 6 outest=_anpre pretime=147 preiter=8
tech = Default
inest = EMWS.AutoNeural_ESTDS bylabel
;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_train_title  ,NOQUOTE, Final Training))";
train estiter=1 outest=_anest outfit=_anfit maxtime=887 maxiter=5
tech = Default;
;
run;
*;
proc print data=_anfit(where=(_name_ eq 'OVERALL')) noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
*------------------------------------------------------------*;
* Extract best iteration;
;
*------------------------------------------------------------*;
%global _iter;
data _null_;
set _anfit(where=(_NAME_ eq 'OVERALL'));
retain _min 1e+64;
if _MISC_ < _min then do;
_min = _MISC_;
call symput('_iter',put(_ITER_, 6.));
end;
run;
*;
data EMWS.AutoNeural_ESTDS;
set _anest;
if _ITER_ eq 0 then do;
output;
stop;
end;
run;
*;
data EMWS.AutoNeural_OUTFIT;
set _anfit;
if _ITER_ eq 0 and _NAME_ eq "OVERALL" then do;
output;
stop;
end;
run;
*;
title9 " ";
title10 "%sysfunc(sasmsg(sashelp.dmine, rpt_selectediteration_title  , NOQUOTE, _MISC_))";
proc print data=EMWS.AutoNeural_OUTFIT noobs;
var _iter_ _aic_ _averr_ _misc_
;
run;
title9;
title10;
*------------------------------------------------------------*;
* AutoNeural Final Network;
;
*------------------------------------------------------------*;
*;
proc neural data=EMWS.BINNING_TRAIN dmdbcat=WORK.AutoNeural_DMDB
;
input %INTINPUTS / level=interval id=interval;
input %BININPUTS / level=nominal id=binary;
input %NOMINPUTS / level=nominal id=nominal;
input %ORDINPUTS / level=ordinal id=ordinal;
target REP_hitel / level=NOMINAL id=REP_hitel
;
*------------------------------------------------------------*;
* Layer #1;
;
*------------------------------------------------------------*;
Hidden 1 / id = H1x1_ act=TANH;
connect interval H1x1_;
connect binary H1x1_;
connect nominal H1x1_;
connect ordinal H1x1_;
connect H1x1_ REP_hitel;
*;
nloptions noprint;
initial inest= EMWS.AutoNeural_ESTDS bylabel;
train tech=none;
code file="C:\Documents and Settings\Sejk\Dokumentumok\My SAS Files\9.1\EM_Projects\lakashitel\Workspaces\EMWS\AutoNeural\SCORECODE.sas"
group=AutoNeural
;
;
code file="C:\Documents and Settings\Sejk\Dokumentumok\My SAS Files\9.1\EM_Projects\lakashitel\Workspaces\EMWS\AutoNeural\RESIDUALSCORECODE.sas"
group=AutoNeural
residual
;
;
score data=EMWS.BINNING_TRAIN out=_NULL_
outfit=WORK.FIT1
role=TRAIN
outkey=EMWS.AutoNeural_OUTKEY;
run;
data EMWS.AutoNeural_OUTFIT;
merge WORK.FIT1;
run;
*------------------------------------------------------------*;
* Generate Weights Plotting data set;
*------------------------------------------------------------*;
data tempweight ( drop = _tech_ _decay_ _seed_ _nobj_ _obj_ _objerr_ _averr_ _p_num_ where= (_type_ eq "PARMS"));
set EMWS.AutoNeural_ESTDS;
run;
proc sort;
by _name_;
run;
proc transpose data=tempweight out=EMWS.AutoNeural_WEIGHTS;
by _name_;
run;
data EMWS.AutoNeural_WEIGHTS;
set EMWS.AutoNeural_WEIGHTS;
FROM = ktrim(kleft(kscan(_LABEL_, 1, '-->')));
TO = ktrim(kleft(kscan(_LABEL_, 2, '>')));
WEIGHT = COL1;
if (TO eq '') or (FROM eq '') then delete;
label _LABEL_ = "%sysfunc(sasmsg(sashelp.dmine, label_vlabel  , NOQUOTE))";
keep FROM TO WEIGHT _LABEL_;
run;
* restore printing options;
;
title10;
options linesize=256;
options pagesize=999;
options nonumber;
options nocenter;
options nodate;
*;
